@@ -1,4 +1,6 @@
-"r" <- function(...) {
+"r" <-
+function (...)
+{
 	# A multiple require proceeding as silently as possible
 	# Suppress packages messages as much as possible
 	owarn <- getOption("warn")
@@ -8,7 +10,7 @@
 	l <- length(args)
 	check <- rep(TRUE, l)
 	if (l > 0)
-		for (i in 1:l) 
+		for (i in 1:l)
 			check[i] <- suppressPackageStartupMessages(require(args[i],
 				quietly = TRUE, character.only = TRUE, warn.conflicts = FALSE))
 	if (!all(check)) {
@@ -21,4 +23,4 @@
 		}
 	}
 	return(invisible(all(check)))
-}
\ No newline at end of file
+}
