@@ -1,5 +1,6 @@
 "rmTemp" <-
-function(x) {
+function (x)
+{
 	if (!is.character(x))
 		stop("'x' must be character string(s)!")
 	l <- length(x)
