@@ -1,4 +1,6 @@
-"tempvar" <- function(pattern = ".var") {
+"tempvar" <-
+function (pattern = ".var")
+{
 	# Similar to tempfile() but for temporary variables
 	repeat {
 		var <- paste(pattern, as.integer(runif(1) * 100000), sep = "")
